From e69d3d01a6b2298d8c228bf33e96f86c3908dc7e Mon Sep 17 00:00:00 2001
From: Peter Eisentraut <peter@eisentraut.org>
Date: Tue, 4 Oct 2022 08:15:13 +0200
Subject: [PATCH 3/4] Use fabsf() instead of Abs() where appropriate

---
 contrib/btree_gist/btree_float4.c | 2 +-
 contrib/intarray/_int_gist.c      | 2 +-
 contrib/seg/seg.c                 | 5 +++--
 3 files changed, 5 insertions(+), 4 deletions(-)

diff --git a/contrib/btree_gist/btree_float4.c b/contrib/btree_gist/btree_float4.c
index 3cbd9a06dccf..84ca5eee5012 100644
--- a/contrib/btree_gist/btree_float4.c
+++ b/contrib/btree_gist/btree_float4.c
@@ -102,7 +102,7 @@ float4_dist(PG_FUNCTION_ARGS)
 	if (unlikely(isinf(r)) && !isinf(a) && !isinf(b))
 		float_overflow_error();
 
-	PG_RETURN_FLOAT4(Abs(r));
+	PG_RETURN_FLOAT4(fabsf(r));
 }
 
 
diff --git a/contrib/intarray/_int_gist.c b/contrib/intarray/_int_gist.c
index f67699bfccc5..331fa25fcf72 100644
--- a/contrib/intarray/_int_gist.c
+++ b/contrib/intarray/_int_gist.c
@@ -540,7 +540,7 @@ g_int_picksplit(PG_FUNCTION_ARGS)
 		union_d = inner_int_union(datum_r, datum_alpha);
 		rt__int_size(union_d, &size_beta);
 		pfree(union_d);
-		costvector[i - 1].cost = fabs((size_alpha - size_l) - (size_beta - size_r));
+		costvector[i - 1].cost = fabsf((size_alpha - size_l) - (size_beta - size_r));
 	}
 	qsort((void *) costvector, maxoff, sizeof(SPLITCOST), comparecost);
 
diff --git a/contrib/seg/seg.c b/contrib/seg/seg.c
index 9b58675266ab..e964560053d1 100644
--- a/contrib/seg/seg.c
+++ b/contrib/seg/seg.c
@@ -10,6 +10,7 @@
 #include "postgres.h"
 
 #include <float.h>
+#include <math.h>
 
 #include "access/gist.h"
 #include "access/stratnum.h"
@@ -706,7 +707,7 @@ rt_seg_size(SEG *a, float *size)
 	if (a == (SEG *) NULL || a->upper <= a->lower)
 		*size = 0.0;
 	else
-		*size = (float) Abs(a->upper - a->lower);
+		*size = fabsf(a->upper - a->lower);
 }
 
 Datum
@@ -714,7 +715,7 @@ seg_size(PG_FUNCTION_ARGS)
 {
 	SEG		   *seg = PG_GETARG_SEG_P(0);
 
-	PG_RETURN_FLOAT4((float) Abs(seg->upper - seg->lower));
+	PG_RETURN_FLOAT4(fabsf(seg->upper - seg->lower));
 }
 
 
-- 
2.37.3

